# remirepo spec file for ImageMagick6
# renamed for parallel installation, from:
#
# Fedora spec file for ImageMagick
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#
%global VER        6.9.10
%global Patchlevel 84
%global incsuffixe -6
%global libsuffixe -6.Q16
%global with_tests 0%{!?_without_tests:1}

%global with_djvu 1
%global with_webp 1
%global with_jp2  1

%if 0%{?fedora} >= 16 || 0%{?rhel} >= 7
%global with_jbig 1
%else
%global with_jbig 0
%endif

%if 0%{?fedora} >= 15 || 0%{?rhel} >= 7
%global with_gslib 1
%else
%global with_gslib 0
%endif

%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7
%global with_raw 1
%else
%global with_raw 0
%endif

%if 0%{?fedora} >= 22 || 0%{?rhel} >= 7
%global with_raqm 1
%else
%global with_raqm 0
%endif

%if 0%{?fedora} || 0%{?rhel} >= 8
%global with_lqr 1
%else
%global with_lqr 0
%endif

%global with_gvc   1

# from mock config, when rpmfusion enabled
%global with_libheif       0%{?_with_rpmfusion:1}

%global libname ImageMagick

%if 0%{?fedora} >= 30 || 0%{?rhel} >= 8
# No need to relocate, same name
%global move    0
%else
%global move    1
%endif

%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
# ImageMagick 7 was briefly sent to Fedora 27 and Rawhide in 2017;
# the epoch was necessary to downgrade them back to 6.
Epoch:                  1
%else
Epoch:                  0
%endif

%if 0%{?fedora} >= 30 || 0%{?rhel} >= 8
Name:           %{libname}
%else
Name:           %{libname}6
%endif
Version:        %{VER}.%{Patchlevel}
Release:        1%{?dist}
Summary:        An X application for displaying and manipulating images
License:        ImageMagick
Url:            http://www.imagemagick.org/
#Source0:        ftp://ftp.ImageMagick.org/pub/ImageMagick/ImageMagick-%{VER}-%{Patchlevel}.tar.xz
Source0:        https://www.imagemagick.org/download/ImageMagick-%{VER}-%{Patchlevel}.tar.xz

BuildRequires:  gcc
BuildRequires:  gcc-c++
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires:  pkgconfig(bzip2)
%else
BuildRequires:  bzip2-devel
%endif
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libpng)
%if 0%{?fedora} || 0%{?rhel} >= 7
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libjpeg)
%else
BuildRequires:  libtiff-devel
BuildRequires:  libjpeg-turbo-devel
%endif
BuildRequires:  giflib-devel
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  perl-devel
BuildRequires:  perl-generators
%if %{with_gslib}
BuildRequires:  libgs-devel
%endif
BuildRequires:  libwmf-devel
BuildRequires:  pkgconfig(jasper)
BuildRequires:  libtool-ltdl-devel
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(lcms2)
%if %{with_raw}
BuildRequires:  pkgconfig(libraw) >= 0.14.8
%endif
%if %{with_webp}
%if 0%{?rhel} == 7
BuildRequires:  libwebp7-devel
%else
BuildRequires:  pkgconfig(libwebp)
%endif
%endif
%if %{with_jbig}
BuildRequires:  jbigkit-devel
%endif
%if %{with_jp2}
%if 0%{?rhel} == 7
# See https://github.com/libvips/libvips/issues/764
# vips pulls poppler (libopenjpeg) and IM (libopenjp2)
BuildRequires:  openjpeg2-static-devel
%else
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires:  pkgconfig(libopenjp2)
%else
BuildRequires:  openjpeg2-devel >= 2.1.0
%endif
%endif
%endif
%if %{with_gvc}
BuildRequires:  graphviz-devel >= 2.9.0
%endif
%if %{with_raqm}
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires:  pkgconfig(raqm)
%else
BuildRequires:  libraqm-devel
%endif
%endif
%if %{with_lqr}
BuildRequires:  liblqr-1-devel
%endif

Requires:       %{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}
Obsoletes:      ImageMagick-last   < %{epoch}:%{version}
Obsoletes:      ImageMagick2-tools < %{epoch}:%{version}

%if "%{name}" != "%{libname}"
# This could be improved in the future
# https://bugzilla.redhat.com/849065
Conflicts:      %{libname}         < %{epoch}:%{version}
Provides:       %{libname}         = %{epoch}:%{version}-%{release}
Provides:       %{libname}%{?_isa} = %{epoch}:%{version}-%{release}
%else
Obsoletes:      %{libname}6       <= %{epoch}:%{version}-%{release}
%endif

# Filter private shared
%{?filter_provides_in: %filter_provides_in %{_libdir}/ImageMagick-%{VER}/modules-Q16/.*$}
%{?filter_setup}


%description
ImageMagick is an image display and manipulation tool for the X
Window System. ImageMagick can read and write JPEG, TIFF, PNM, GIF,
and Photo CD image formats. It can resize, rotate, sharpen, color
reduce, or add special effects to an image, and when finished you can
either save the completed work in the original format or a different
one. 

ImageMagick-last includes the command line programs for creating animated or
transparent .gifs, creating composite images, creating thumbnail images,
and more.
%if "%{name}" != "%{libname}"
%{name} conflicts with ImageMagick official RPM and so can not
be installed together.
%endif


%package devel
Summary: Library links and header files for ImageMagick app development
Requires: %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires: libX11-devel, libXext-devel, libXt-devel
Requires: ghostscript-devel%{?_isa}
Requires: bzip2-devel%{?_isa}
Requires: freetype-devel%{?_isa}
Requires: libtiff-devel%{?_isa}
Requires: libjpeg-devel%{?_isa}
Requires: OpenEXR-devel%{?_isa}
Requires: lcms2-devel%{?_isa}
%if %{with_webp}
%if 0%{?rhel} == 7
Requires: libwebp7-devel%{?_isa}
%else
Requires: libwebp-devel%{?_isa}
%endif
%endif
%if %{with_jbig}
Requires: jbigkit-devel%{?_isa}
%endif
%if %{with_jp2}
Requires: openjpeg2-devel%{?_isa}
%endif
Requires: jasper-devel%{?_isa}
Requires: pkgconfig
%if "%{name}" != "%{libname}"
Conflicts: %{libname}-devel         < %{epoch}:%{version}
Provides:  %{libname}-devel         = %{epoch}:%{version}-%{release}
Provides:  %{libname}-devel%{?_isa} = %{epoch}:%{version}-%{release}
Obsoletes: ImageMagick-last-devel   < %{epoch}:%{version}
%else
Obsoletes: %{libname}6-devel       <= %{epoch}:%{version}-%{release}
%endif

%description devel
ImageMagick-last-devel contains the library links and header files you'll
need to develop ImageMagick applications. ImageMagick is an image
manipulation program.

If you want to create applications that will use ImageMagick code or
APIs, you need to install ImageMagick-devel as well as ImageMagick.
You do not need to install it if you just want to use ImageMagick,
however.


%package libs
Summary: Commands for ImageMagick
Obsoletes: ImageMagick2          < %{epoch}:%{version}
Obsoletes: ImageMagick-last-libs < %{epoch}:%{version}
%if "%{name}" == "%{libname}"
Obsoletes: %{libname}6-libs     <= %{epoch}:%{version}-%{release}
%endif

%description libs
Provides the shared libraries and plugins of %{name}.
%if "%{name}" != "%{libname}"
This package could be installed beside official RPM of ImageMagick
for applications requiring this libraries.
%endif


%if %{with_djvu}
%package djvu
Summary: DjVu plugin for ImageMagick
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires:  pkgconfig(ddjvuapi)
%else
BuildRequires:  djvulibre-devel
%endif
Requires: %{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}
Obsoletes: ImageMagick-last-djvu < %{epoch}:%{version}
%if "%{name}" == "%{libname}"
Obsoletes: %{libname}6-djvu     <= %{epoch}:%{version}-%{release}
%endif

%description djvu
This packages contains a plugin for ImageMagick which makes it possible to
save and load DjvU files from ImageMagick and libMagickCore using applications.
%if "%{name}" != "%{libname}"
This package could be installed beside official RPM of ImageMagick-djvu
for applications requiring this libraries.
%endif
%endif


%if %{with_libheif}
%package heic
Summary: HEIC plugin for ImageMagick
BuildRequires:	pkgconfig(libheif)
Requires: %{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}
%if "%{name}" == "%{libname}"
Obsoletes: %{libname}6-heic   <= %{epoch}:%{version}-%{release}
%endif

%description heic
This packages contains a plugin for ImageMagick which makes it possible to
save and load HEIC files from ImageMagick and libMagickCore using applications.
%if "%{name}" != "%{libname}"
This package could be installed beside official RPM of ImageMagick-heic
for applications requiring this libraries.
%endif
%endif


%package doc
Summary: ImageMagick html documentation
BuildRequires:  doxygen
Obsoletes: ImageMagick-last-doc < %{epoch}:%{version}
%if "%{name}" == "%{libname}"
Obsoletes: %{libname}6-doc     <= %{epoch}:%{version}-%{release}
%endif

%description doc
ImageMagick documentation, this package contains usage (for the
commandline tools) and API (for the libraries) documentation in html format.

    %{_datadir}/%{name}/doc/ImageMagick%{?incsuffixe}/www/

Note this documentation can also be found on the ImageMagick website:
http://www.imagemagick.org/


%package perl
Summary: ImageMagick perl bindings
Requires: %{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}
Requires: perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
%if "%{name}" != "%{libname}"
Conflicts: %{libname}-perl         < %{epoch}:%{version}
Provides:  %{libname}-perl         = %{epoch}:%{version}-%{release}
Provides:  %{libname}-perl%{?_isa} = %{epoch}:%{version}-%{release}
Obsoletes: ImageMagick-last-perl   < %{epoch}:%{version}
%else
Obsoletes: %{libname}6-perl       <= %{epoch}:%{version}-%{release}
%endif

%description perl
Perl bindings to ImageMagick.

Install ImageMagick-perl if you want to use any perl scripts that use
ImageMagick.


%package c++
Summary: ImageMagick Magick++ library (C++ bindings)
Requires: %{name}-libs%{?_isa} = %{epoch}:%{version}-%{release}
Obsoletes: ImageMagick-last-c++ < %{epoch}:%{version}
%if "%{name}" == "%{libname}"
Obsoletes: %{libname}6-c++     <= %{epoch}:%{version}-%{release}
%endif

%description c++
This package contains the Magick++ library, a C++ binding to the ImageMagick
graphics manipulation library.

Install ImageMagick-c++ if you want to use any applications that use Magick++.
%if "%{name}" != "%{libname}"
This package could be installed beside official RPM of ImageMagick-c++
for applications requiring this libraries.
%endif


%package c++-devel
Summary: C++ bindings for the ImageMagick library
Requires: %{name}-c++%{?_isa} = %{epoch}:%{version}-%{release}
Requires: %{name}-devel%{?_isa} = %{epoch}:%{version}-%{release}
%if "%{name}" != "%{libname}"
Conflicts: %{libname}-c++-devel         < %{epoch}:%{version}
Provides:  %{libname}-c++-devel         = %{epoch}:%{version}-%{release}
Provides:  %{libname}-c++-devel%{?_isa} = %{epoch}:%{version}-%{release}
Obsoletes: ImageMagick-last-c++-devel   < %{epoch}:%{version}
%else
Obsoletes: %{libname}6-c++-devel       <= %{epoch}:%{version}-%{release}
%endif

%description c++-devel
ImageMagick-devel contains the static libraries and header files you'll
need to develop ImageMagick applications using the Magick++ C++ bindings.
ImageMagick is an image manipulation program.

If you want to create applications that will use Magick++ code
or APIs, you'll need to install ImageMagick-c++-devel, ImageMagick-devel and
ImageMagick.
You don't need to install it if you just want to use ImageMagick, or if you
want to develop/compile applications using the ImageMagick C interface,
however.


%prep
%setup -q -n %{libname}-%{VER}-%{Patchlevel}

# for %%doc
mkdir Magick++/examples
cp -p Magick++/demo/*.cpp Magick++/demo/*.miff Magick++/examples


%build
export CFLAGS="%{optflags} -DIMPNG_SETJMP_IS_THREAD_SAFE"

%configure --enable-shared \
           --disable-static \
           --disable-silent-rules \
           --with-modules \
           --with-perl \
           --with-x \
           --with-threads \
           --with-magick_plus_plus \
%if %{with_raqm}
           --with-raqm \
%else
           --without-raqm \
%endif
%if %{with_gslib}
           --with-gslib \
%else
           --without-gslib \
%endif
           --with-wmf \
           --with-lcms \
           --with-openexr \
%if %{with_raw}
           --with-raw \
%else
           --without-raw \
%endif
           --with-rsvg \
           --with-xml \
%if %{with_webp}
           --with-webp \
%else
           --without-webp \
%endif
%if %{with_jbig}
           --with-jbig \
%else
           --without-jbig \
%endif
%if %{with_jp2}
           --with-openjp2 \
%else
           --without-openjp2 \
%endif
%if %{with_lqr}
           --with-lqr \
%else
           --without-lqr \
%endif
%if %{with_gvc}
           --with-gvc \
%endif
%if %{with_libheif}
           --with-heif \
%else
           --without-heif \
%endif
           --with-perl-options="INSTALLDIRS=vendor %{?perl_prefix} CC='%__cc -L$PWD/magick/.libs' LDDLFLAGS='-shared -L$PWD/magick/.libs'" \
           --without-dps \
%if %{move}
           --datadir=%{_datadir}/%{name} \
           --sysconfdir=%{_sysconfdir}/%{name} \
%endif
           --without-gcc-arch

# Do *NOT* use %%{?_smp_mflags}, this causes PerlMagick to be silently misbuild
make

# Generate API docs
make html-local


%install
make install DESTDIR=%{buildroot} INSTALL="install -p"
# Delete *ONLY* _libdir/*.la files! .la files used internally to handle plugins - BUG#185237!!!
rm %{buildroot}%{_libdir}/*.la

# fix weird perl module permissions
chmod 755 %{buildroot}%{perl_vendorarch}/auto/Image/Magick/Q16/Q16.so

# perlmagick: fix perl path of demo files
%{__perl} -MExtUtils::MakeMaker -e 'MY->fixin(@ARGV)' PerlMagick/demo/*.pl

# perlmagick: cleanup various perl tempfiles from the build which get installed
find %{buildroot} -name "*.bs" |xargs rm -f
find %{buildroot} -name ".packlist" |xargs rm -f
find %{buildroot} -name "perllocal.pod" |xargs rm -f

# perlmagick: build files list
find %{buildroot}/%{_libdir}/perl* -type f -print \
        | sed "s@^%{buildroot}@@g" > perl-pkg-files
find %{buildroot}%{perl_vendorarch} -type d -print \
        | sed "s@^%{buildroot}@%dir @g" \
        | grep -v '^%dir %{perl_vendorarch}$' \
        | grep -v '/auto$' >> perl-pkg-files 
if [ -z perl-pkg-files ] ; then
    echo "ERROR: EMPTY FILE LIST"
    exit -1
fi

# fix multilib issues: Rename provided file with platform-bits in name.
# Create platform independant file inplace of provided and conditionally include required.
# $1 - filename.h to process.
function multilibFileVersions(){
mv $1 ${1%%.h}-%{__isa_bits}.h

local basename=$(basename $1)

cat >$1 <<EOF
#include <bits/wordsize.h>

#if __WORDSIZE == 32
# include "${basename%%.h}-32.h"
#elif __WORDSIZE == 64
# include "${basename%%.h}-64.h"
#else
# error "unexpected value for __WORDSIZE macro"
#endif
EOF
}

multilibFileVersions %{buildroot}%{_includedir}/%{libname}-6/magick/magick-config.h
multilibFileVersions %{buildroot}%{_includedir}/%{libname}-6/magick/magick-baseconfig.h
multilibFileVersions %{buildroot}%{_includedir}/%{libname}-6/magick/version.h


%if %{with_tests}
%check
export LD_LIBRARY_PATH=%{buildroot}/%{_libdir}
make %{?_smp_mflags} check
%endif


%pre libs
LIB=%{_libdir}/%{libname}-%{VER}
%if %{move}
ETC=%{_sysconfdir}/%{name}
%else
ETC=%{_sysconfdir}/%{libname}%{?incsuffixe}
%endif
if [ -d $ETC -a ! -d $LIB ]; then cat << EOF

WARNING : %{name} modules directory have changed.
You need to restart some services to take care of
the new location (e.g. httpd, php-fpm).

EOF
fi

%if 0%{?fedora} < 28 && 0%{?rhel} < 8
%post libs -p /sbin/ldconfig
%post c++  -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig
%postun c++  -p /sbin/ldconfig
%endif


%files
%{_bindir}/[a-z]*
%{_mandir}/man[145]/[a-z]*
%{_mandir}/man1/%{libname}.*

%files libs
%doc ChangeLog
%doc README.txt LICENSE NOTICE AUTHORS.txt NEWS.txt
%{_libdir}/libMagickCore%{?libsuffixe}.so.6*
%{_libdir}/libMagickWand%{?libsuffixe}.so.6*
%{_libdir}/%{libname}-%{VER}
%if %{move}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{libname}%{?incsuffixe}
%dir               %{_sysconfdir}/%{name}
%dir               %{_sysconfdir}/%{name}/%{libname}%{?incsuffixe}
%config(noreplace) %{_sysconfdir}/%{name}/%{libname}%{?incsuffixe}/*.xml
%else
%{_datadir}/%{libname}%{?incsuffixe}
%dir               %{_sysconfdir}/%{libname}%{?incsuffixe}
%config(noreplace) %{_sysconfdir}/%{libname}%{?incsuffixe}/*.xml
%endif
%if %{with_djvu}
%exclude %{_libdir}/%{libname}-%{VER}/modules-Q16/coders/djvu.*
%endif
%if %{with_libheif}
%exclude %{_libdir}/%{libname}-%{VER}/modules-Q16/coders/heic.*
%endif

%files devel
%{_bindir}/MagickCore-config
%{_bindir}/Magick-config
%{_bindir}/MagickWand-config
%{_bindir}/Wand-config
%{_libdir}/libMagickCore%{?libsuffixe}.so
%{_libdir}/libMagickWand%{?libsuffixe}.so
%{_libdir}/pkgconfig/MagickCore%{?libsuffixe}.pc
%{_libdir}/pkgconfig/MagickCore.pc
%{_libdir}/pkgconfig/%{libname}%{?libsuffixe}.pc
%{_libdir}/pkgconfig/%{libname}.pc
%{_libdir}/pkgconfig/MagickWand%{?libsuffixe}.pc
%{_libdir}/pkgconfig/MagickWand.pc
%{_libdir}/pkgconfig/Wand%{?libsuffixe}.pc
%{_libdir}/pkgconfig/Wand.pc
%dir %{_includedir}/%{libname}%{?incsuffixe}
%{_includedir}/%{libname}%{?incsuffixe}/magick
%{_includedir}/%{libname}%{?incsuffixe}/wand
%{_mandir}/man1/Magick-config.*
%{_mandir}/man1/MagickCore-config.*
%{_mandir}/man1/Wand-config.*
%{_mandir}/man1/MagickWand-config.*

%if %{with_djvu}
%files djvu
%{_libdir}/%{libname}-%{VER}/modules-Q16/coders/djvu.*
%endif

%if %{with_libheif}
%files heic
%{_libdir}/%{libname}-%{VER}/modules-Q16/coders/heic.*
%endif

%files doc
%if %{move}
%doc %{_datadir}/%{name}/doc/%{libname}%{?incsuffixe}
%else
%doc %{_datadir}/doc/%{libname}%{?incsuffixe}
%endif

%files c++
%doc Magick++/AUTHORS Magick++/ChangeLog Magick++/NEWS Magick++/README
%doc www/Magick++/COPYING
%{_libdir}/libMagick++%{?libsuffixe}.so.8*

%files c++-devel
%doc Magick++/examples
%{_bindir}/Magick++-config
%{_includedir}/%{libname}%{?incsuffixe}/Magick++
%{_includedir}/%{libname}%{?incsuffixe}/Magick++.h
%{_libdir}/libMagick++%{?libsuffixe}.so
%{_libdir}/pkgconfig/Magick++%{?libsuffixe}.pc
%{_libdir}/pkgconfig/Magick++.pc
%{_libdir}/pkgconfig/ImageMagick++%{?libsuffixe}.pc
%{_libdir}/pkgconfig/ImageMagick++.pc
%{_mandir}/man1/Magick++-config.*

%files perl -f perl-pkg-files
%{_mandir}/man3/*
%doc PerlMagick/demo/ PerlMagick/Changelog PerlMagick/README.txt


%changelog
* Mon Jan  6 2020 Remi Collet <remi@remirepo.net> - 6.9.10.84-1
- update to version 6.9.10 patch level 84

* Thu Jan  2 2020 Remi Collet <remi@remirepo.net> - 6.9.10.83-1
- update to version 6.9.10 patch level 83

* Tue Dec 31 2019 Remi Collet <remi@remirepo.net> - 6.9.10.82-1
- update to version 6.9.10 patch level 82

* Wed Dec 18 2019 Remi Collet <remi@remirepo.net> - 6.9.10.79-1
- update to version 6.9.10 patch level 79

* Mon Dec  9 2019 Remi Collet <remi@remirepo.net> - 6.9.10.78-1
- update to version 6.9.10 patch level 78

* Mon Dec  2 2019 Remi Collet <remi@remirepo.net> - 6.9.10.77-1
- update to version 6.9.10 patch level 77

* Wed Nov 27 2019 Remi Collet <remi@remirepo.net> - 6.9.10.75-1
- update to version 6.9.10 patch level 75

* Mon Nov 18 2019 Remi Collet <remi@remirepo.net> - 6.9.10.74-1
- update to version 6.9.10 patch level 74

* Sat Nov 16 2019 Remi Collet <remi@remirepo.net> - 6.9.10.73-1
- update to version 6.9.10 patch level 73

* Thu Nov 14 2019 Remi Collet <remi@remirepo.net> - 6.9.10.72-1
- update to version 6.9.10 patch level 72

* Thu Oct 31 2019 Remi Collet <remi@remirepo.net> - 6.9.10.71-1
- update to version 6.9.10 patch level 71

* Tue Oct 29 2019 Remi Collet <remi@remirepo.net> - 6.9.10.70-1
- update to version 6.9.10 patch level 70

* Sat Oct 26 2019 Remi Collet <remi@remirepo.net> - 6.9.10.69-1
- update to version 6.9.10 patch level 69

* Mon Oct  7 2019 Remi Collet <remi@remirepo.net> - 6.9.10.68-1
- update to version 6.9.10 patch level 68

* Mon Sep 30 2019 Remi Collet <remi@remirepo.net> - 6.9.10.67-1
- update to version 6.9.10 patch level 67

* Wed Sep 25 2019 Remi Collet <remi@remirepo.net> - 6.9.10.66-2
- enable again gslilb on EL-7
  https://github.com/remicollet/remirepo/issues/127
- using patched libpaper

* Mon Sep 23 2019 Remi Collet <remi@remirepo.net> - 6.9.10.66-1
- update to version 6.9.10 patch level 66

* Thu Sep 19 2019 Remi Collet <remi@remirepo.net> - 6.9.10.65-1
- update to version 6.9.10 patch level 65
- disable gslib on EL-7
  https://github.com/ImageMagick/ImageMagick/issues/1699
  https://bugzilla.redhat.com/1753534

* Mon Sep  9 2019 Remi Collet <remi@remirepo.net> - 6.9.10.64-1
- update to version 6.9.10 patch level 64

* Mon Sep  2 2019 Remi Collet <remi@remirepo.net> - 6.9.10.63-1
- update to version 6.9.10 patch level 63

* Mon Aug 26 2019 Remi Collet <remi@remirepo.net> - 6.9.10.62-1
- update to version 6.9.10 patch level 62

* Mon Aug 19 2019 Remi Collet <remi@remirepo.net> - 6.9.10.61-1
- update to version 6.9.10 patch level 61

* Thu Aug  8 2019 Remi Collet <remi@remirepo.net> - 6.9.10.59-2
- rebuild with LibRaw 0.19.2 in RHEL 7.7

* Mon Aug  5 2019 Remi Collet <remi@remirepo.net> - 6.9.10.59-1
- update to version 6.9.10 patch level 59

* Mon Jul 22 2019 Remi Collet <remi@remirepo.net> - 6.9.10.56-1
- update to version 6.9.10 patch level 56
- drop patch merged upstream

* Wed Jul 17 2019 Remi Collet <remi@remirepo.net> - 6.9.10.54-1
- update to version 6.9.10 patch level 54
- build with IMPNG_SETJMP_IS_THREAD_SAFE
- fix pkgconfig files using patch from
  https://github.com/ImageMagick/ImageMagick6/pull/53

* Mon Jul  8 2019 Remi Collet <remi@remirepo.net> - 6.9.10.53-1
- update to version 6.9.10 patch level 53

* Tue Jul  2 2019 Remi Collet <remi@remirepo.net> - 6.9.10.51-1
- update to version 6.9.10 patch level 51

* Tue Jun 25 2019 Remi Collet <remi@remirepo.net> - 6.9.10.50-1
- update to version 6.9.10 patch level 50

* Wed Jun 12 2019 Remi Collet <remi@remirepo.net> - 6.9.10.49-1
- update to version 6.9.10 patch level 49
- Generate local API docs with doxygen (FeRD)

* Mon Jun  3 2019 Remi Collet <remi@remirepo.net> - 6.9.10.48-1
- update to version 6.9.10 patch level 48

* Mon May 20 2019 Remi Collet <remi@remirepo.net> - 6.9.10.46-1
- update to version 6.9.10 patch level 46

* Mon May 13 2019 Remi Collet <remi@remirepo.net> - 6.9.10.45-1
- update to version 6.9.10 patch level 45
- add HEIC support using libheif from RPMFusion
  in optional heic subpackage

* Tue May  7 2019 Remi Collet <remi@remirepo.net> - 6.9.10.44-2
- fix missing epoch in obsoletes

* Mon May  6 2019 Remi Collet <remi@remirepo.net> - 6.9.10.44-1
- update to version 6.9.10 patch level 44

* Thu May  2 2019 Remi Collet <remi@remirepo.net> - 6.9.10.43-1
- update to version 6.9.10 patch level 43

* Thu Apr 25 2019 Remi Collet <remi@remirepo.net> - 6.9.10.42-1
- update to version 6.9.10 patch level 42

* Tue Apr 23 2019 Remi Collet <remi@remirepo.net> - 6.9.10.41-1
- update to version 6.9.10 patch level 41

* Mon Apr 15 2019 Remi Collet <remi@remirepo.net> - 6.9.10.40-1
- update to version 6.9.10 patch level 40

* Mon Apr  8 2019 Remi Collet <remi@remirepo.net> - 6.9.10.39-1
- update to version 6.9.10 patch level 39

* Thu Apr  4 2019 Remi Collet <remi@remirepo.net> - 6.9.10.37-1
- update to version 6.9.10 patch level 37

* Mon Apr  1 2019 Remi Collet <remi@remirepo.net> - 6.9.10.36-1
- update to version 6.9.10 patch level 36

* Mon Mar 25 2019 Remi Collet <remi@remirepo.net> - 6.9.10.35-1
- update to version 6.9.10 patch level 35
- open https://github.com/ImageMagick/ImageMagick6/issues/37 failed test

* Mon Mar 18 2019 Remi Collet <remi@remirepo.net> - 6.9.10.34-1
- update to version 6.9.10 patch level 34
- use libwebp7 on EL-7

* Mon Mar 11 2019 Remi Collet <remi@remirepo.net> - 6.9.10.33-1
- update to version 6.9.10 patch level 33

* Thu Mar  7 2019 Remi Collet <remi@remirepo.net> - 6.9.10.32-1
- update to version 6.9.10 patch level 32

* Mon Mar  4 2019 Remi Collet <remi@remirepo.net> - 6.9.10.30-1
- update to version 6.9.10 patch level 30

* Thu Feb 28 2019 Remi Collet <remi@remirepo.net> - 6.9.10.29-1
- update to version 6.9.10 patch level 29

* Mon Feb 18 2019 Remi Collet <remi@remirepo.net> - 6.9.10.28-1
- update to version 6.9.10 patch level 28

* Mon Feb 11 2019 Remi Collet <remi@remirepo.net> - 6.9.10.27-1
- update to version 6.9.10 patch level 27

* Wed Feb  6 2019 Remi Collet <remi@remirepo.net> - 6.9.10.26-1
- update to version 6.9.10 patch level 26

* Thu Jan 31 2019 Remi Collet <remi@remirepo.net> - 6.9.10.25-1
- update to version 6.9.10 patch level 25

* Fri Jan 18 2019 Remi Collet <remi@remirepo.net> - 6.9.10.24-1
- update to version 6.9.10 patch level 24

* Wed Jan  2 2019 Remi Collet <remi@remirepo.net> - 6.9.10.23-1
- update to version 6.9.10 patch level 23

* Thu Dec 27 2018 Remi Collet <remi@remirepo.net> - 6.9.10.20-1
- update to version 6.9.10 patch level 20

* Fri Dec 21 2018 Remi Collet <remi@remirepo.net> - 6.9.10.19-1
- update to version 6.9.10 patch level 19

* Thu Dec 20 2018 Remi Collet <remi@remirepo.net> - 6.9.10.18-1
- update to version 6.9.10 patch level 18
- add dependency on libzstd

* Wed Dec 19 2018 Remi Collet <remi@remirepo.net> - 6.9.10.17-1
- update to version 6.9.10 patch level 17

* Tue Dec 11 2018 Remi Collet <remi@remirepo.net> - 6.9.10.16-1
- update to version 6.9.10 patch level 16
- keep PerlMagick/demo/Generic.ttf used by test suite

* Mon Dec  3 2018 Remi Collet <remi@remirepo.net> - 6.9.10.15-1
- update to version 6.9.10 patch level 15

* Thu Oct 25 2018 Remi Collet <remi@remirepo.net> - 6.9.10.14-1
- update to version 6.9.10 patch level 14

* Tue Oct 23 2018 Remi Collet <remi@remirepo.net> - 6.9.10.13-1
- update to version 6.9.10 patch level 13

* Mon Sep 24 2018 Remi Collet <remi@remirepo.net> - 6.9.10.12-1
- update to version 6.9.10 patch level 12

* Thu Aug 30 2018 Remi Collet <remi@remirepo.net> - 6.9.10.11-1
- update to version 6.9.10 patch level 11

* Fri Aug 17 2018 Remi Collet <remi@remirepo.net> - 6.9.10.10-1
- update to version 6.9.10 patch level 10

* Tue Jul 24 2018 Remi Collet <remi@remirepo.net> - 6.9.10.8-1
- update to version 6.9.10 patch level 8

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 6.9.10.7-1
- update to version 6.9.10 patch level 7

* Tue Jul 10 2018 Remi Collet <remi@remirepo.net> - 6.9.10.6-1
- update to version 6.9.10 patch level 6

* Mon Jul  9 2018 Remi Collet <remi@remirepo.net> - 6.9.10.5-1
- update to version 6.9.10 patch level 5

* Wed Jul  4 2018 Remi Collet <remi@remirepo.net> - 6.9.10.4-1
- update to version 6.9.10 patch level 4

* Mon Jun 25 2018 Remi Collet <remi@remirepo.net> - 6.9.10.3-1
- update to version 6.9.10 patch level 3

* Wed Jun 20 2018 Remi Collet <remi@remirepo.net> - 6.9.10.2-2
- change perl version from 6.9A to 6.99 for old perl
  fix Invalid version format (non-numeric data)
  reported as https://github.com/ImageMagick/ImageMagick6/issues/11

* Tue Jun 19 2018 Remi Collet <remi@remirepo.net> - 6.9.10.2-1
- update to version 6.9.10 patch level 2

* Wed Jun 13 2018 Remi Collet <remi@remirepo.net> - 6.9.10.0-1
- update to version 6.9.10

* Tue Jun 12 2018 Remi Collet <remi@remirepo.net> - 6.9.9.51-1
- update to version 6.9.9 patch level 51

* Mon Jun  4 2018 Remi Collet <remi@remirepo.net> - 6.9.9.50-1
- update to version 6.9.9 patch level 50

* Tue May 29 2018 Remi Collet <remi@remirepo.net> - 6.9.9.47-1
- update to version 6.9.9 patch level 47
- libMagickCore soname bump to 6
- libMagickWand soname bump to 6
- open https://github.com/ImageMagick/ImageMagick/issues/1150 version bump
- open https://github.com/mkoppanen/imagick/issues/247 imagick segfault

* Tue Mar 27 2018 Remi Collet <remi@remirepo.net> - 6.9.9.40-1
- update to version 6.9.9 patch level 40

* Tue Mar 20 2018 Remi Collet <remi@remirepo.net> - 6.9.9.39-1
- update to version 6.9.9 patch level 39

* Mon Mar 12 2018 Remi Collet <remi@remirepo.net> - 6.9.9.38-1
- update to version 6.9.9 patch level 38
- re-enable gslib on F28

* Mon Mar  5 2018 Remi Collet <remi@remirepo.net> - 6.9.9.37-2
- build without gslib on F28

* Mon Mar  5 2018 Remi Collet <remi@remirepo.net> - 6.9.9.37-1
- update to version 6.9.9 patch level 37

* Mon Feb 26 2018 Remi Collet <remi@remirepo.net> - 6.9.9.36-1
- update to version 6.9.9 patch level 36

* Tue Feb 20 2018 Remi Collet <remi@remirepo.net> - 6.9.9.35-1
- update to version 6.9.9 patch level 35

* Tue Jan 23 2018 Remi Collet <remi@remirepo.net> - 6.9.9.34-1
- update to version 6.9.9 patch level 34

* Mon Jan  8 2018 Remi Collet <remi@remirepo.net> - 6.9.9.33-1
- update to version 6.9.9 patch level 33

* Tue Jan  2 2018 Remi Collet <remi@remirepo.net> - 6.9.9.31-1
- update to version 6.9.9 patch level 31

* Fri Dec 29 2017 Remi Collet <remi@remirepo.net> - 6.9.9.30-1
- update to version 6.9.9 patch level 30

* Thu Dec 28 2017 Remi Collet <remi@remirepo.net> - 6.9.9.29-1
- update to version 6.9.9 patch level 29

* Tue Dec 26 2017 Remi Collet <remi@remirepo.net> - 6.9.9.28-1
- update to version 6.9.9 patch level 28

* Mon Dec 18 2017 Remi Collet <remi@remirepo.net> - 6.9.9.27-1
- update to version 6.9.9 patch level 27

* Wed Dec  6 2017 Remi Collet <remi@remirepo.net> - 6.9.9.26-1
- update to version 6.9.9 patch level 26

* Mon Dec  4 2017 Remi Collet <remi@remirepo.net> - 6.9.9.25-1
- update to version 6.9.9 patch level 25

* Thu Nov 30 2017 Remi Collet <remi@remirepo.net> - 6.9.9.24-2
- add upstream patch for #888

* Thu Nov 30 2017 Remi Collet <remi@remirepo.net> - 6.9.9.24-1
- update to version 6.9.9 patch level 24
- open https://github.com/ImageMagick/ImageMagick/issues/888
  build failure with libraw 0.14.8 (in EL-7)

* Mon Nov 13 2017 Remi Collet <remi@remirepo.net> - 6.9.9.23-1
- update to version 6.9.9 patch level 23

* Tue Nov  7 2017 Remi Collet <remi@remirepo.net> - 6.9.9.22-1
- update to version 6.9.9 patch level 22

* Wed Nov  1 2017 Remi Collet <remi@remirepo.net> - 6.9.9.21-1
- update to version 6.9.9 patch level 21

* Mon Oct 16 2017 Remi Collet <remi@remirepo.net> - 6.9.9.20-1
- update to version 6.9.9 patch level 20

* Mon Oct  9 2017 Remi Collet <remi@remirepo.net> - 6.9.9.19-1
- update to version 6.9.9 patch level 19

* Thu Oct  5 2017 Remi Collet <remi@remirepo.net> - 6.9.9.18-1
- update to version 6.9.9 patch level 18

* Wed Oct  4 2017 Remi Collet <remi@remirepo.net> - 6.9.9.17-2
- test build with openjpeg2 static library on EL-7

* Mon Oct  2 2017 Remi Collet <remi@remirepo.net> - 6.9.9.17-1
- update to version 6.9.9 patch level 17

* Mon Sep 25 2017 Remi Collet <remi@remirepo.net> - 6.9.9.15-1
- update to version 6.9.9 patch level 15

* Wed Sep 20 2017 Remi Collet <remi@remirepo.net> - 6.9.9.14-1
- update to version 6.9.9 patch level 14

* Wed Sep 13 2017 Remi Collet <remi@remirepo.net> - 6.9.9.13-1
- update to version 6.9.9 patch level 13

* Sun Sep 10 2017 Remi Collet <remi@remirepo.net> - 6.9.9.12-1
- update to version 6.9.9 patch level 12

* Wed Sep  6 2017 Remi Collet <remi@remirepo.net> - 6.9.9.11-2
- revert to v6 in F27+

* Mon Sep  4 2017 Remi Collet <remi@remirepo.net> - 6.9.9.11-1
- update to version 6.9.9 patch level 11

* Mon Aug 28 2017 Remi Collet <remi@remirepo.net> - 6.9.9.10-1
- update to version 6.9.9 patch level 10

* Fri Aug 25 2017 Remi Collet <remi@remirepo.net> - 6.9.9.9-2
- build as ImageMagick on F25 / F26 and obsoletes ImageMagick6
- build as ImageMagick6 on F27

* Tue Aug 22 2017 Remi Collet <remi@remirepo.net> - 6.9.9.9-1
- update to version 6.9.9 patch level 9

* Mon Aug 21 2017 Remi Collet <remi@remirepo.net> - 6.9.9.8-1
- update to version 6.9.9 patch level 8

* Sun Aug 13 2017 Remi Collet <remi@remirepo.net> - 6.9.9.7-1
- update to version 6.9.9 patch level 7

* Fri Aug 11 2017 Remi Collet <remi@remirepo.net> - 6.9.9.6-1
- update to version 6.9.9 patch level 6

* Sat Aug  5 2017 Remi Collet <remi@remirepo.net> - 6.9.9.5-1
- update to version 6.9.9 patch level 5
- libMagickCore soname bump to 5
- libMagickWand soname bump to 5
- libMagick++ soname bump to 8
- enable raw support

* Mon Jun 12 2017 Remi Collet <remi@remirepo.net> - 6.9.8.10-1
- update to version 6.9.8 patch level 10

* Tue Jun  6 2017 Remi Collet <remi@remirepo.net> - 6.9.8.9-1
- update to version 6.9.8 patch level 9

* Mon May 29 2017 Remi Collet <remi@remirepo.net> - 6.9.8.8-1
- update to version 6.9.8 patch level 8

* Sun May 28 2017 Remi Collet <remi@remirepo.net> - 6.9.8.7-2
- add upstream patch for #501
- use --with-openjp2 option on Enterprise Linux

* Sun May 28 2017 Remi Collet <remi@remirepo.net> - 6.9.8.7-1
- update to version 6.9.8 patch level 7
- open https://github.com/ImageMagick/ImageMagick/issues/501
  failed tests retaled to openjp2

* Mon May 22 2017 Remi Collet <remi@remirepo.net> - 6.9.8.6-1
- update to version 6.9.8 patch level 6

* Sun May 14 2017 Remi Collet <remi@remirepo.net> - 6.9.8.5-1
- update to version 6.9.8 patch level 5

* Tue Apr 25 2017 Remi Collet <remi@remirepo.net> - 6.9.8.4-1
- update to version 6.9.8 patch level 4

* Sun Mar 26 2017 Remi Collet <remi@remirepo.net> - 6.9.8.3-1
- update to version 6.9.8 patch level 3

* Mon Mar 20 2017 Remi Collet <remi@remirepo.net> - 6.9.8.2-1
- update to version 6.9.8 patch level 2

* Thu Mar 16 2017 Remi Collet <remi@remirepo.net> - 6.9.8.0-2
- cleanup build options
- build --with-raqm when available
- build --with-lqr when available

* Sun Mar 12 2017 Remi Collet <remi@remirepo.net> - 6.9.8.0-1
- update to version 6.9.8

* Sun Mar  5 2017 Remi Collet <remi@remirepo.net> - 6.9.7.10-1
- update to version 6.9.7 patch level 10

* Sat Feb 18 2017 Remi Collet <remi@remirepo.net> - 6.9.7.9-1
- update to version 6.9.7 patchlevel 9

* Tue Feb 14 2017 Remi Collet <remi@remirepo.net> - 6.9.7.8-1
- update to version 6.9.7 patchlevel 8

* Mon Feb  6 2017 Remi Collet <remi@remirepo.net> - 6.9.7.7-1
- update to version 6.9.7 patchlevel 7

* Sat Jan 28 2017 Remi Collet <remi@remirepo.net> - 6.9.7.6-1
- update to version 6.9.7 patchlevel 6
- libMagickCore and libMagickWand soname bump to 4

* Sun Jan 22 2017 Remi Collet <remi@remirepo.net> - 6.9.7.5-1
- update to version 6.9.7 patchlevel 5

* Mon Jan 16 2017 Remi Collet <remi@remirepo.net> - 6.9.7.4-1
- update to version 6.9.7 patchlevel 4

* Sun Jan  8 2017 Remi Collet <remi@remirepo.net> - 6.9.7.3-1
- update to version 6.9.7 patchlevel 3

* Wed Jan  4 2017 Remi Collet <remi@remirepo.net> - 6.9.7.2-1
- update to version 6.9.7 patchlevel 2

* Mon Jan  2 2017 Remi Collet <remi@remirepo.net> - 6.9.7.1-1
- update to version 6.9.7 patchlevel 1 (broken)
- open https://github.com/ImageMagick/ImageMagick/issues/340

* Mon Dec 19 2016 Remi Collet <remi@remirepo.net> - 6.9.7.0-1
- update to version 6.9.7

* Sun Dec 11 2016 Remi Collet <remi@remirepo.net> - 6.9.6.8-1
- update to version 6.9.6 patchlevel 8
- new soname libMagickCore=3, libMagickWand=3, libMagick++=7
- rename to ImageMagick6

* Tue Dec  6 2016 Remi Collet <remi@remirepo.net> - 6.9.6.7-1
- update to version 6.9.6 patchlevel 7

* Sat Nov 26 2016 Remi Collet <remi@remirepo.net> - 6.9.6.6-1
- update to version 6.9.6 patchlevel 6

* Tue Nov 15 2016 Remi Collet <remi@remirepo.net> - 6.9.6.5-1
- update to version 6.9.6 patchlevel 5

* Wed Nov  9 2016 Remi Collet <remi@remirepo.net> - 6.9.6.4-1
- update to version 6.9.6 patchlevel 4

* Tue Nov  1 2016 Remi Collet <remi@remirepo.net> - 6.9.6.3-1
- update to version 6.9.6 patchlevel 3

* Tue Oct 11 2016 Remi Collet <remi@remirepo.net> - 6.9.6.2-1
- update to version 6.9.6 patchlevel 2

* Sun Oct  9 2016 Remi Collet <remi@remirepo.net> - 6.9.6.1-1
- update to version 6.9.6 patchlevel 1

* Mon Oct  3 2016 Remi Collet <remi@remirepo.net> - 6.9.6.0-1
- update to version 6.9.6

* Wed Sep 21 2016 Remi Collet <remi@remirepo.net> - 6.9.5.10-1
- update to version 6.9.5 patchlevel 10
- flag configuration files as %%config

* Tue Sep  6 2016 Remi Collet <remi@remirepo.net> - 6.9.5.9-1
- update to version 6.9.5 patchlevel 9

* Fri Sep  2 2016 Remi Collet <remi@remirepo.net> - 6.9.5.8-1
- update to version 6.9.5 patchlevel 8

* Mon Aug  8 2016 Remi Collet <remi@remirepo.net> - 6.9.5.5-1
- update to version 6.9.5 patchlevel 5
- add upstream patch for
  https://github.com/ImageMagick/ImageMagick/issues/245

* Sat Jul 30 2016 Remi Collet <remi@remirepo.net> - 6.9.5.4-1
- update to version 6.9.5 patchlevel 4

* Sat Jul 23 2016 Remi Collet <remi@remirepo.net> - 6.9.5.3-1
- update to version 6.9.5 patchlevel 3

* Tue Jul 12 2016 Remi Collet <remi@remirepo.net> - 6.9.5.2-1
- update to version 6.9.5 patchlevel 2

* Sun Jul 10 2016 Remi Collet <remi@remirepo.net> - 6.9.5.1-1
- update to version 6.9.5 patchlevel 1

* Thu Jun 30 2016 Remi Collet <remi@remirepo.net> - 6.9.5.0-1
- update to version 6.9.5
- display update message when modules directory change
- fix scriplets

* Fri Jun 24 2016 Remi Collet <remi@remirepo.net> - 6.9.4.10-1
- update to version 6.9.4 patchlevel 10

* Mon Jun 13 2016 Remi Collet <remi@remirepo.net> - 6.9.4.9-1
- update to version 6.9.4 patchlevel 9

* Sat Jun 11 2016 Remi Collet <remi@remirepo.net> - 6.9.4.8-2
- add patch for cache time limit
  open https://github.com/ImageMagick/ImageMagick/pull/219

* Thu Jun  9 2016 Remi Collet <remi@remirepo.net> - 6.9.4.8-1
- update to version 6.9.4 patchlevel 8

* Fri Jun  3 2016 Remi Collet <remi@remirepo.net> - 6.9.4.7-1
- update to version 6.9.4 patchlevel 7

* Fri Jun  3 2016 Remi Collet <remi@remirepo.net> - 6.9.4.6-1
- update to version 6.9.4 patchlevel 6

* Fri May 27 2016 Remi Collet <remi@remirepo.net> - 6.9.4.4-1
- update to version 6.9.4 patchlevel 4

* Thu May 19 2016 Remi Collet <remi@remirepo.net> - 6.9.4.3-1
- update to version 6.9.4 patchlevel 3

* Wed May 18 2016 Remi Collet <remi@remirepo.net> - 6.9.4.2-1
- update to version 6.9.4 patchlevel 2
- open https://github.com/ImageMagick/ImageMagick/issues/202
  6.9.4-2 failed test validate-formats-disk.tap

* Wed May 11 2016 Remi Collet <remi@remirepo.net> - 6.9.4.1-1
- update to version 6.9.4 patchlevel 1

* Wed May  4 2016 Remi Collet <remi@remirepo.net> - 6.9.3.10-1
- update to version 6.9.3 patchlevel 10

* Mon May  2 2016 Remi Collet <remi@remirepo.net> - 6.9.3.9-1
- update to version 6.9.3 patchlevel 9

* Tue Apr 12 2016 Remi Collet <remi@remirepo.net> - 6.9.3.8-1
- update to version 6.9.3 patchlevel 8

* Mon Mar  7 2016 Remi Collet <remi@remirepo.net> - 6.9.3.7-1
- update to version 6.9.3 patchlevel 7

* Tue Mar  1 2016 Remi Collet <remi@remirepo.net> - 6.9.3.6-1
- update to version 6.9.3 patchlevel 6

* Mon Feb 22 2016 Remi Collet <remi@remirepo.net> - 6.9.3.5-1
- update to version 6.9.3 patchlevel 5

* Sat Feb 13 2016 Remi Collet <remi@remirepo.net> - 6.9.3.4-1
- update to 6.9.3-4

* Sun Feb  7 2016 Remi Collet <remi@remirepo.net> - 6.9.3.3-1
- update to 6.9.3-3

* Sat Jan 23 2016 Remi Collet <remi@remirepo.net> - 6.9.3.2-1
- update to 6.9.3-2

* Mon Jan 18 2016 Remi Collet <remi@remirepo.net> - 6.9.3.1-1
- update to 6.9.3-1
- various improvements from Fedora (multi-lib)
- run "make check" during the build

* Mon Jan  4 2016 Remi Collet <remi@remirepo.net> - 6.9.3.0-1
- update to 6.9.3-0

* Sat Dec 26 2015 Remi Collet <remi@remirepo.net> - 6.9.2.10-1
- update to 6.9.2-10

* Sun Dec  6 2015 Remi Collet <remi@remirepo.net> - 6.9.2.8-1
- update to 6.9.2-8

* Sun Nov 29 2015 Remi Collet <remi@remirepo.net> - 6.9.2.7-1
- update to 6.9.2-7

* Tue Nov 17 2015 Remi Collet <remi@remirepo.net> - 6.9.2.6-1
- update to 6.9.2-6

* Sun Nov  1 2015 Remi Collet <remi@remirepo.net> - 6.9.2.5-1
- update to 6.9.2-5

* Sun Oct 11 2015 Remi Collet <remi@remirepo.net> - 6.9.2.4-1
- update to 6.9.2-4

* Sun Sep 20 2015 Remi Collet <remi@remirepo.net> - 6.9.2.3-1
- update to 6.9.2-3

* Mon Sep 14 2015 Remi Collet <remi@remirepo.net> - 6.9.2.1-1
- update to 6.9.2-1

* Wed Aug 26 2015 Remi Collet <remi@remirepo.net> - 6.9.2.0-1
- update to 6.9.2-0

* Mon Jul 27 2015 Remi Collet <remi@remirepo.net> - 6.9.1.10-1
- update to 6.9.1-10

* Tue Jul 21 2015 Remi Collet <remi@remirepo.net> - 6.9.1.9-1
- update to 6.9.1-9

* Wed Jul 15 2015 Remi Collet <remi@remirepo.net> - 6.9.1.8-1
- update to 6.9.1-8

* Mon Jul  6 2015 Remi Collet <remi@remirepo.net> - 6.9.1.7-1
- update to 6.9.1-7
- build with gvc support (graphviz)

* Mon Jun 22 2015 Remi Collet <remi@remirepo.net> - 6.9.1.6-1
- update to 6.9.1-6

* Mon Jun 15 2015 Remi Collet <remi@remirepo.net> - 6.9.1.5-1
- update to 6.9.1-5

* Tue Jun  2 2015 Remi Collet <remi@remirepo.net> - 6.9.1.4-1
- update to 6.9.1-4

* Thu May 28 2015 Remi Collet <remi@remirepo.net> - 6.9.1.3-2
- honors default build options (--without-gcc-arch)
- make build verbose

* Mon May 25 2015 Remi Collet <remi@remirepo.net> - 6.9.1.3-1
- update to 6.9.1-3

* Mon May  4 2015 Remi Collet <RPMS@FamilleCollet.com> - 6.9.1.2-1.2
- rebuild with libcms2 in EL-5

* Thu Apr 23 2015 Remi Collet <RPMS@FamilleCollet.com> - 6.9.1.2-1.1
- rebuild for new libwebp in EPEL-6

* Tue Apr 21 2015 Remi Collet <RPMS@FamilleCollet.com> - 6.9.1.2-1
- update to 6.9.1-2
- add jbig support (fedora and EL-7)
- add jp2 support (fedora 21+)

* Wed Apr  8 2015 Remi Collet <RPMS@FamilleCollet.com> - 6.9.1.1-1
- update to 6.9.1-1

* Fri Jan 23 2015 Remi Collet <RPMS@FamilleCollet.com> - 6.9.0.4-1
- update to 6.9.0-4

* Fri Jan  2 2015 Remi Collet <RPMS@FamilleCollet.com> - 6.9.0.2-1
- update to 6.9.0-2

* Wed Nov  5 2014 Remi Collet <RPMS@FamilleCollet.com> - 6.8.9.10-1
- update to 6.8.9-10

* Fri Sep 19 2014 Remi Collet <RPMS@FamilleCollet.com> - 6.8.9.7-4
- don't use libgs with old ghostscript

* Wed Sep 17 2014 Remi Collet <RPMS@FamilleCollet.com> - 6.8.9.7-3
- revert change in coder/pdf.c which cause a regression
  with old ghostcript 8.70

* Wed Aug 27 2014 Remi Collet <RPMS@FamilleCollet.com> - 6.8.9.7-2
- revert change in coder/ps.c which cause a regression
  with old ghostcript 8.70

* Mon Aug 25 2014 Remi Collet <RPMS@FamilleCollet.com> - 6.8.9.7-1
- update to 6.8.9-7
- soname change: libMagick++-6.Q16.so.5

* Mon Apr 14 2014 Remi Collet <RPMS@FamilleCollet.com> - 6.8.9.0-2
- use /usr/share/ImageMagick-last to avoid conflict (f20)

* Mon Apr 14 2014 Remi Collet <RPMS@FamilleCollet.com> - 6.8.9.0-1
- update to 6.8.9-0

* Sat Nov 02 2013 Remi Collet <RPMS@FamilleCollet.com> - 6.8.7.4-2
- update to 6.8.7-4
- enable webp support in EL

* Thu Sep 19 2013 Remi Collet <RPMS@FamilleCollet.com> - 6.8.6.10-1
- update to 6.8.6-10
- soname change: libMagick++-6.Q16.so.3

* Tue Sep 17 2013 Stefan Pommerening <pom@dmsp.de> - 6.8.6.10-1
- update to 6.8.6-10

* Sun Sep  8 2013 Remi Collet <RPMS@FamilleCollet.com> - 6.8.6.9-1
- update to 6.8.6-9
- filter privates modules from provides

* Sun Jun  2 2013 Remi Collet <RPMS@FamilleCollet.com> - 6.8.5.9-1
- update to 6.8.5-9
- enable --with-webp when available
- enable --with-openexr
- enable --with-lcms2 when available, instead of --with-lcms

* Mon May  6 2013 Remi Collet <RPMS@FamilleCollet.com> - 6.8.5.4-1
- update to 6.8.5-4
- enable fftw to do Fourier transforms

* Sat Apr  6 2013 Remi Collet <RPMS@FamilleCollet.com> - 6.8.4.6-1
- update to 6.8.4-6

* Wed Mar 13 2013 Remi Collet <RPMS@FamilleCollet.com> - 6.8.3.9-1
- update to 6.8.3-9

* Wed Aug 15 2012 Remi Collet <RPMS@FamilleCollet.com> - 6.7.8.10-1
- rename to ImageMagick-last
- update to 6.7.8-10 (soname bump to .5)

* Thu Nov 25 2010 Remi Collet <RPMS@FamilleCollet.com> - 6.6.5.10-1
- update to 6.6.5-10 (soname bump to .4)

* Sat Sep 05 2009 Remi Collet <RPMS@FamilleCollet.com> - 6.5.5.6-1
- patch level 6

* Wed Aug 26 2009 Remi Collet <RPMS@FamilleCollet.com> - 6.5.5.2-1
- rename to ImageMagick2 for EL and Fedora <= 10

* Mon Aug  3 2009 Pavel Alexeev <Pahan@Hubbitus.info> - 6.5.4.7-3
- Update to version 6.5.4-7
- Use lzma-compressed source tarball as sugested by Ville Skyttä (BZ#515319)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.5.3.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jun 15 2009 Hans de Goede <hdegoede@redhat.com> 6.5.3.7-1
- New upstream release 6.5.3-7

* Mon Apr 13 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 6.5.1.2-1
- update to 6.5.1-2

* Fri Mar 13 2009 Hans de Goede <hdegoede@redhat.com> 6.4.9.6-2
- Fix undefined warning in magick-type.h (#489453)
- Do not link PerlMagick against system ImageMagick, but against the just
  build one

* Mon Mar  9 2009 Hans de Goede <hdegoede@redhat.com> 6.4.9.6-1
- New upstream release 6.4.9-6

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.4.5.5-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Jan 30 2009 Hans de Goede <hdegoede@redhat.com> 6.4.5.5-8
- Remove (TM) from description as per new guidelines

* Sat Jan 17 2009 Rakesh Pandit <rakesh@fedoraproject.org> 6.4.5.5-7
- Corrected the wrong release and bumped

* Sat Jan 17 2009 Rakesh Pandit <rakesh@fedoraproject.org> 6.4.5.5-6
- Rebuild with new djvulibre

* Sat Dec 27 2008 Hans de Goede <hdegoede@redhat.com> 6.4.5.5-5
- Remove 2 included copies of the non Free artbrush font (rh 477399)

* Wed Dec 10 2008 Hans de Goede <hdegoede@redhat.com> 6.4.5.5-4
- Do not pass -jX to make when building, this breaks PerlMagick (rh 475554)

* Wed Nov 19 2008 Hans de Goede <hdegoede@redhat.com> 6.4.5.5-3
- Remove --without-windows-font-dir from configure args, specifying it
  makes ImageMagick search for windows fonts in the "no/" dir (rh 472244)

* Fri Nov 14 2008 Hans de Goede <hdegoede@redhat.com> 6.4.5.5-2
- Enable djvu support, put the new djvu plugin into a separate -djvu
  subpackage because of deps (rh 225897)

* Fri Nov 14 2008 Hans de Goede <hdegoede@redhat.com> 6.4.5.5-1
- New upstream release 6.4.5-5
- Various specfile fixes from merge review (rh 225897)
- Fix building with new libtool (rh 471468)

* Thu Nov 13 2008 Hans de Goede <hdegoede@redhat.com> 6.4.0.10-3
- Rebuild for new libtool (rh 471468)

* Sun Jul 27 2008 Hans de Goede <jwrdegoede@fedoraproject.org> 6.4.0.10-2
- Fix ownership of /usr/include/ImageMagick (bz 444647)

* Sat Apr 26 2008 Hans de Goede <jwrdegoede@fedoraproject.org> 6.4.0.10-1
- New upstream release 6.4.0.10
- This fixes conversion of 24 bpp windows icons (bz 440136)
- Don't reuse GError structs, that upsets glib2 (bz 325211)
- Use the system ltdl, not the included copy (bz 237475)
- Fix various multilib conflicts (bz 341561)
- Use xdg-open instead of htmlview (bz 388451)
- Some small specfile cleanups (utf-8 stuff & others) fixing rpmlint warnings

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 6.3.8.1-3
- Rebuild for perl 5.10 (again)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 6.3.8.1-2
- Autorebuild for GCC 4.3

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> 6.3.8.1-1
- update to 6.3.8.1
- rebuild for new perl
- fix license tag
- fix rpath issues
- add sparc64 to 64bit arch list

* Fri Sep 21 2007 Norm Murray <nmurray@redhat.com> 6.3.5.9-1.fc8
- rebase to 6.3.5.9
- fix build with missing open() arg
- add build require of jasper-devel, remove windows font dir
- update multilib patch

* Thu Apr  5 2007 Norm Murray <nmurray@redhat.com> 6.3.2.9-3.fc7
- heap overflows (#235075, CVE-2007-1797)

* Fri Mar 30 2007 Norm Murray <nmurray@redhat.com> 6.3.2.9-2.fc7
- perlmagick build fix (#231259)

* Fri Mar  2 2007 Norm Murray <nmurray@redhat.com> 6.3.2.9-1.fc7.0
- update to 6.3.2-9

* Wed Aug 23 2006 Matthias Clasen <mclasen@redhat.com> - 6.2.8.0-3.fc6
- fix several integer and buffer overflows (#202193, CVE-2006-3743)
- fix more integer overflows (#202771, CVE-2006-4144)

* Mon Jul 24 2006 Matthias Clasen <mclasen@redhat.com> - 6.2.8.0-2
- Add missing BRs

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 6.2.8.0-1.1
- rebuild

* Fri Jun  9 2006 Matthias Clasen <mclasen@redhat.com> - 6.2.8-1
- Update to 6.2.8

* Fri Jun  2 2006 Matthias Clasen <mclasen@redhat.com> - 6.2.5.4-7
- Fix multilib issues

* Thu May 25 2006 Matthias Clasen <mclasen@redhat.com> - 6.2.5.4-6
- Fix a heap overflow CVE-2006-2440 (#192279)
- Include required .la files  

* Mon Mar 20 2006 Matthias Clasen <mclasen@redhat.com> - 6.2.5.4-5
- Don't ship .la and .a files (#185237)

* Mon Feb 13 2006 Jesse Keating <jkeating@redhat.com> - 6.2.5.4-4.2.1
- rebump for build order issues during double-long bump

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 6.2.5.4-4.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 6.2.5.4-4.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Mon Jan 30 2006 Matthias Clasen <mclasen@redhat.com> 6.2.5.4-4
- Make -devel require lcms-devel (#179200)

* Mon Jan 23 2006 Matthias Clasen <mclasen@redhat.com> 6.2.5.4-3
- Fix linking of DSOs.  (#176695)

* Mon Jan  9 2006 Matthias Clasen <mclasen@redhat.com> 6.2.5.4-2
- fix a format string vulnerability (CVE-2006-0082)

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Tue Nov  1 2005 Matthias Clasen <mclasen@redhat.com> 6.2.5.4-1
- Switch requires to modular X
- Update to 6.2.5

* Tue Sep 20 2005 Matthias Clasen <mclasen@redhat.com> 6.2.4.6-1
- Update to 6.2.4-6
- Drop upstreamed patches
- Disable DPS (#158984)
- Add missing requires (#165931)

* Thu Jun  9 2005 Tim Waugh <twaugh@redhat.com> 6.2.2.0-4
- Rebuilt for fixed ghostscript.

* Mon Jun  6 2005 Tim Waugh <twaugh@redhat.com> 6.2.2.0-3
- Rebuilt for new ghostscript.

* Thu May 26 2005  <mclasen@redhat.com> - 6.2.2.0-2
- fix a denial of service in the xwd coder (#158791, CAN-2005-1739)

* Tue Apr 26 2005 Matthias Clasen <mclasen@redhat.com> - 6.2.2.0-1
- Update to 6.2.2 to fix a heap corruption issue
  in the pnm coder.
 
* Mon Apr 25 2005  Matthias Clasen <mclasen@redhat.com> - 6.2.1.7-4
- .la files for modules are needed, actually

* Mon Apr 25 2005  Matthias Clasen <mclasen@redhat.com> - 6.2.1.7-3
- Really remove .la files for modules

* Mon Apr 25 2005  <mclasen@redhat.com> - 6.2.1.7-1
- Update to 6.2.1
- Include multiple improvements and bugfixes
  by Rex Dieter et al (111961, 145466, 151196, 149970, 
  146518, 113951, 145449, 144977, 144570, 139298)

* Sun Apr 24 2005  <mclasen@redhat.com> - 6.2.0.7-3
- Make zip compression work for tiff (#154045)

* Wed Mar 16 2005  <mclasen@redhat.com> - 6.2.0.7-2
- Update to 6.2.0 to fix a number of security issues:
  #145112 (CAN-2005-05), #151265 (CAN-2005-0397)
- Drop a lot of upstreamed patches

* Wed Mar  2 2005 Matthias Clasen <mclasen@redhat.com> 6.0.7.1-7
- rebuild with gcc4
- remove an extraneous vsnprintf prototype which causes
  gcc4 to complain

* Mon Oct 11 2004 Tim Waugh <twaugh@redhat.com> 6.0.7.1-4
- The devel subpackage requires XFree86-devel (bug #126509).
- Fixed build requirements (bug #120776).  From Robert Scheck.

* Tue Sep 14 2004 Karsten Hopp <karsten@redhat.de> 6.0.7.1-3 
- move *.mgk files (#132007, #131708, #132397)

* Sun Sep 12 2004 Karsten Hopp <karsten@redhat.de> 6.0.7.1-1 
- update to 6.0.7 Patchlevel 1, fixes #132106

* Sat Sep  4 2004 Bill Nottingham <notting@redhat.com> 6.0.6.2-2
- move libWand out of -devel, fix requirements (#131767)

* Wed Sep 01 2004 Karsten Hopp <karsten@redhat.de> 6.0.6.2-1 
- update to latest stable version
- get rid of obsolete patches
- fix remaining patches

* Sat Jun 19 2004 Alan Cox <alan@redhat.com>
- Easyfixes (#124791) - fixed missing dependancy between -devel and
  libexif-devel

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Mar 23 2004 Karsten Hopp <karsten@redhat.de> 5.5.7.15-1.3 
- freetype patch to fix convert (#115716)

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Sun Jan 25 2004 Nils Philippsen <nphilipp@redhat.com> 5.5.7.15-0.2
- make perl module link against the built library instead of the installed one

* Thu Jan 22 2004 Nils Philippsen <nphilipp@redhat.com> 5.5.7.15-0.1
- version 5.5.7 patchlevel 15

* Mon Oct 13 2003 Nils Philippsen <nphilipp@redhat.com> 5.5.7.10-0.1
- rebuild with release 0.1 to not block an official update package

* Wed Sep 10 2003 Nils Philippsen <nphilipp@redhat.com> 5.5.7.10-2
- hack around libtool stupidity
- disable automake patch as we require automake-1.7 anyway

* Wed Sep 10 2003 Nils Philippsen <nphilipp@redhat.com> 5.5.7.10-1
- version 5.5.7 patchlevel 10

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu May 29 2003 Tim Powers <timp@redhat.com> 5.5.6-4
- rebuild for RHEL to fix broken deps

* Thu May 15 2003 Tim Powers <timp@redhat.com> 5.5.6-3
- rebuild again to fix broken dep on libMagick.so.5

* Mon May 12 2003 Karsten Hopp <karsten@redhat.de> 5.5.6-2
- rebuild

* Fri May 09 2003 Karsten Hopp <karsten@redhat.de> 5.5.6-1
- update
- specfile fixes
  #63897 (_target instead of _arch)
  #74521 (SRPM doesn't compile)
  #80441 (RFE: a newer version of ImageMagick is available)
  #88450 (-devel package missing dependancy)
  #57396 (convert won't read RAW format images)
- verified that the upstream version fixes the following bugreports:
  #57544 (display cannot handle many xpm's which both ee and rh71 display can)
  #63727 (ImageMagick fails to handle RGBA files)
  #73864 (composite dumps core on certain operations)
  #78242 (Header files for c missing in devel rpms)
  #79783 (magick_config.h is missing from ImageMagick-c++-devel)
  #80117 (Documentation is installed twice by RPM )
  #82762 (Trouble with browsing help files)
  #85760 (Segmentation fault)
  #86120 (eps->ppm convert crashes)

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Sat Jan  4 2003 Jeff Johnson <jbj@redhat.com> 5.4.7-9
- use internal dep generator.

* Mon Dec 16 2002 Tim Powers <timp@redhat.com> 5.4.7-8
- rebuild

* Sat Dec 14 2002 Tim Powers <timp@redhat.com> 5.4.7-7
- don't use rpms internal dep generator

* Fri Nov 22 2002 Tim Powers <timp@redhat.com>
- fix perl paths in file list

* Thu Nov 21 2002 Tim Powers <timp@redhat.com>
- lib64'ize
- don't throw stuff in /usr/X11R6, that's for X only
- remove files we aren't shipping

* Sat Aug 10 2002 Elliot Lee <sopwith@redhat.com>
- rebuilt with gcc-3.2 (we hope)

* Tue Jul 23 2002 Tim Powers <timp@redhat.com> 5.4.7-4
- build using gcc-3.2-0.1

* Wed Jul 03 2002 Karsten Hopp <karsten@redhat.de> 5.4.7-3
- fix non-cpp headers in -devel package
- fix #62157 (wrong path for include files in ImageMagick-devel)
- fix #63897 (use _target instead of _arch) in libtool workaround
- fix #65860, #65780 (tiff2ps) expands images to >10 MB Postscript files.

* Mon Jul 01 2002 Karsten Hopp <karsten@redhat.de> 5.4.7-1
- update
- fix localdoc patch
- fix %%files section
- disable nonroot patch
- fix #62100,55950,62162,63136 (display doesn't start form gnome menu)
- fix libtool workaround
- moved Magick*-config into -devel package (#64249)

* Sun May 26 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Mon May  6 2002 Bernhard Rosenkraenzer <bero@redhat.com> 5.4.6-1
- 5.4.6

* Thu Mar 14 2002 Bernhard Rosenkraenzer <bero@redhat.com> 5.4.3.11-1
- Update to pl 11

* Fri Feb 22 2002 Bernhard Rosenkraenzer <bero@redhat.com> 5.4.3.5-1
- Update to 5.4.3 pl5; this fixes #58080

* Thu Jan 17 2002 Bernhard Rosenkraenzer <bero@redhat.com> 5.4.2.3-1
- Patchlevel 3

* Wed Jan 09 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Fri Jan  4 2002 Bernhard Rosenkraenzer <bero@redhat.com> 5.4.2.2-1
- Update to 5.4.2-2
- Fix #57923, also don't hardcode netscape as html viewer

* Wed Dec  5 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.4.1-1
- 5.4.1
- Link against new libstdc++

* Fri Nov  9 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.4.0.5-1
- 5.4.0.5
- Make the error message when trying to display an hpgl file more
  explicit (#55875)

* Mon Nov  5 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.4.0.3-1
- 5.4.0.3
- Fix names of man pages

* Mon Oct 22 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.4.0-1
- 5.4.0
- work around build system breakage causing applications to be named
  %%{_arch}-redhat-linux-foo rather than foo

* Wed Sep 19 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.9-1
- 5.3.9

* Mon Aug 27 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.8-3
- Add delegates.mgk back, got lost during the update to 5.3.8 (Makefile bug)
  (#52611)

* Mon Aug 20 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.8-2
- Remove Magick++ includes from -devel, they're already in -c++-devel
  (#51590)

* Sat Jul 28 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.8-1
- 5.3.8 (bugfix release)

* Fri Jul 27 2001 Than Ngo <than@redhat.com> 5.3.7-3
- fix to build Perlmagic on s390 s390x

* Thu Jul 26 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.7-2
- Add delegates.mgk to the package (#50725)

* Tue Jul 24 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.7-1
- 5.3.7
- Fix build without previously installed ImageMagick-devel (#49816)
- Move perl bindings to a separate package.

* Mon Jul  9 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.6-2
- Fix build as non-root again
- Shut up rpmlint

* Tue Jul  3 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.6-1
- 5.3.6
- Get rid of the ia64 patch, it's no longer needed since glibc was fixed

* Sat Jun 16 2001 Than Ngo <than@redhat.com>
- update to 5.3.5
- cleanup specfile

* Sat May 19 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.3-2
- 5.3.3-respin, fixes #41196

* Tue May  1 2001 Bernhard Rosenkraenzer <bero@redhat.com> 5.3.3-1
- 5.3.3
- Add a desktop file for "display" (RFE#17417)

* Sun Apr 15 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 5.3.2
- work around bugs in ia64 glibc headers

* Mon Jan 08 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- remove patch for s390, it is not necessary

* Mon Jan  1 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 5.2.7

* Wed Dec 27 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 5.2.6

* Mon Dec 18 2000 Than Ngo <than@redhat.com>
- ported to s390

* Mon Sep 25 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 5.2.4
- Fix up and package the C++ bindings in the new c++/c++-devel packages.

* Wed Aug  2 2000 Matt Wilson <msw@redhat.com>
- rebuild against new libpng

* Wed Jul 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- include images with docs (#10312)

* Thu Jul 13 2000 Matt Wilson <msw@redhat.com>
- don't build with -ggdb, use -g instead.

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Mon Jul  3 2000 Florian La Roche <laroche@redhat.com>
- update to 5.2.2 beta

* Mon Jul  3 2000 Florian La Roche <laroche@redhat.com>
- update to 5.2.1, redone patches as they failed

* Fri Jun 30 2000 Matt Wilson <msw@redhat.com>
- remove hacks to move perl man pages
- don't include the perl*/man stuff, these files go in /usr/share/man now.

* Thu Jun 15 2000 Nalin Dahyabhai <nalin@redhat.com>
- disable optimization on Alpha and Sparc

* Wed Jun 14 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 5.2.0
- update URL
- remove redundant CXXFLAGS=$RPM_OPT_FLAGS

* Thu Jun  1 2000 Matt Wilson <msw@redhat.com>
- bootstrap rebuilt to nuke broken libbz2 deps
- add Prefix: tag such that the FHS macros work properly

* Wed May 17 2000 Trond Eivind Glomsrød <teg@redhat.com>
- now compiles with bzip2 1.0
- changed buildroot to include version

* Fri May  5 2000 Bill Nottingham <notting@redhat.com>
- fix compilation with new perl

* Sat Mar 18 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 5.1.1

* Thu Feb  3 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Rebuild to get compressed man pages

* Thu Nov 18 1999 Michael K. Johnson <johnsonm@redhat.com>
- ugly hack to print with lpr instead of lp

* Mon Aug 30 1999 Bill Nottingham <notting@redhat.com>
- update to 4.2.9

* Tue Aug 17 1999 Bill Nottingham <notting@redhat.com>
- update to 4.2.8

* Fri Apr 09 1999 Cristian Gafton <gafton@redhat.com>
- include the perl man pages as well

* Tue Apr 06 1999 Michael K. Johnson <johnsonm@redhat.com>
- remove --enable-16bit because it damages interoperability

* Mon Apr  5 1999 Bill Nottingham <notting@redhat.com>
- update to 4.2.2
- change ChangeLog to refer to actual dates. 
- strip binaries

* Thu Apr  1 1999 Bill Nottingham <notting@redhat.com>
- add more files. Oops.

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 2)

* Wed Mar 10 1999 Bill Nottingham <notting@redhat.com>
- version 4.2.1

* Tue Jan 19 1999 Michael K. Johnson <johnsonm@redhat.com>
- changed group

* Tue Jan 19 1999 Cristian Gafton <gafton@redhat.com>
- hacks to make it work with the new perl
- version 4.1.0 (actually installs the sonames as 4.0.10... doh!)
- make sure the libraries have the x bit on

* Wed Jun 10 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Tue Apr 21 1998 Cristian Gafton <gafton@redhat.com>
- updated to 4.0.5

* Wed Apr 08 1998 Cristian Gafton <gafton@redhat.com>
- updated to 4.0.4
- added BuildRoot

* Thu Oct 23 1997 Donnie Barnes <djb@redhat.com>
- updated from 3.8.3 to 3.9.1
- removed PNG patch (appears to be fixed)

* Wed Oct 15 1997 Erik Troan <ewt@redhat.com>
- build against new libpng

* Thu Jul 10 1997 Erik Troan <ewt@redhat.com>
- built against glibc

* Thu Mar 20 1997 Michael Fulbright <msf@redhat.com>
- updated to version 3.8.3.
- updated source and url tags.
